%define module	scipy
%define name	python-%{module}
%define version 0.6.0
%define release 8

Summary:	Scientific tools for Python
Name:		%{name}
Version:	%{version}
Release:	%mkrel %{release}
Source0:	%{module}-%{version}.tar.bz2
Source1:	randomkit.tar.bz2
Patch0:		sandbox-setup.patch
Patch1:		montecarlo-setup.py.patch
Patch2:		montecarlo.py.patch
Patch3:		umfpack-setup.py.patch
Source2:	enabled_packages.txt
License:	BSD
Group:		Development/Python
BuildRoot:	%{_tmppath}/%{name}-buildroot
Url:		http://www.scipy.org
Obsoletes:	python-SciPy
Requires:	python, python-numpy >= 1.0
BuildRequires:	swig
BuildRequires:	python-devel, fftw-devel, blas-devel, lapack-devel 
BuildRequires:	python-numpy-devel >= 1.0, python-numpy >= 1.0
BuildRequires:	gcc >= 4.0, gcc-gfortran >= 4.0
BuildRequires:	libx11-devel, netcdf-devel
# Needed to prevent older amd/umfpack devel packages from interfering with
# build on 2008.0:
%if %mdkversion < 200810
BuildRequires:	amd-devel = 2.2.0, umfpack-devel = 5.2.0
%else
BuildRequires:	amd-devel, umfpack-devel
%endif

%description
SciPy is an open source library of scientific tools for Python. SciPy
supplements the popular numpy module, gathering a variety of high level
science and engineering modules together as a single package.

SciPy includes modules for graphics and plotting, optimization, integration,
special functions, signal and image processing, genetic algorithms, ODE 
solvers, and others.

%prep
%setup -n %{module}-%{version} -q
%patch0 -p0
%patch1 -p0
%patch2 -p0
%patch3 -p0

%__tar jfx %SOURCE1 -C ./scipy/sandbox/montecarlo/src
%__cp %SOURCE2 ./scipy/sandbox/

%build

# Use netlib BLAS/LAPACK:
export BLAS=%{_libdir}/libblas.a
export LAPACK=%{_libdir}/liblapack.a
export ATLAS=None

# Make sure that gcc 4 is being used to build the package:
GCC_VERSION=`gcc --version | awk 'NR == 1 {print $3}'`
if echo $GCC_VERSION | grep ^4 > /dev/null; then
   export CC=gcc-$GCC_VERSION
else
   echo "Need GCC 4 to build"
   exit 1
fi

export CC=gcc-$GCC_VERSION

CFLAGS="-fPIC" %__python setup.py config_fc --fcompiler=gnu95 build

%install
%__rm -rf %{buildroot}

export BLAS=%{_libdir}/libblas.a
export LAPACK=%{_libdir}/liblapack.a
export ATLAS=None

%__python setup.py config_fc --fcompiler=gnu95 install --root=%{buildroot} --record=INSTALLED_FILES.tmp

# Don't include original test files:
%__grep -Ev "\\.orig$" INSTALLED_FILES.tmp > INSTALLED_FILES

## Uncomment the following once the scipy tests are stable ##
#%check
#export PYTHONPATH=%{buildroot}/%{_libdir}/python%{pyver}/site-packages/
#echo $PYTHONPATH
# python -c "import scipy; scipy.test(level=1, verbosity=2)"

%clean
%__rm -rf %{buildroot}

%files -f INSTALLED_FILES
%defattr(-,root,root)
%doc *.txt






%changelog
* Mon Jul 14 2008 Funda Wang <fundawang@mandriva.org> 0.6.0-8mdv2009.0
+ Revision: 234449
- rebuild for new lapack layout

* Mon Jun 16 2008 Lev Givon <lev@mandriva.org> 0.6.0-6mdv2009.0
+ Revision: 220136
- Rebuild against numpy 1.1.0.
  Disable netcdf sandbox package because it doesn't compile properly.

* Thu Jan 03 2008 Lev Givon <lev@mandriva.org> 0.6.0-5mdv2008.1
+ Revision: 141003
- Specify amd-devel and umfpack-devel versions to enable build of 0.6.0
  on 2008.0.

* Tue Jan 01 2008 Lev Givon <lev@mandriva.org> 0.6.0-4mdv2008.1
+ Revision: 140144
- Tweak buildreqs in light of the refactored suitesparse packages.

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Nov 13 2007 Lev Givon <lev@mandriva.org> 0.6.0-3mdv2008.1
+ Revision: 108470
- Bump release to rebuild against lapack 3.1.1.
- Add patch to allow python-scipy to build against umfpack 5.
- Update to 0.6.0.

* Wed Aug 22 2007 Lev Givon <lev@mandriva.org> 0.5.2.1-1mdv2008.0
+ Revision: 69187
- Update to 0.5.2.1.

* Wed Jun 20 2007 Lev Givon <lev@mandriva.org> 0.5.2-6mdv2008.0
+ Revision: 41866
- Apply patches to allow 0.5.2 to build against numpy 1.0.3.

* Wed Apr 18 2007 Lev Givon <lev@mandriva.org> 0.5.2-5mdv2008.0
+ Revision: 14357
- Bump release to force build against numpy 1.0.2.


* Wed Feb 21 2007 Lev Givon <lev@mandriva.org> 0.5.2-4mdv2007.0
+ Revision: 123942
- Fix python issue in montecarlo.py
- Add netcdf-devel build dependency.
- Tweak.
- Add X11 build dependency for xplt.
- Add randomkit so that the montecarlo package can be built.
- Enable various sandbox packages.
- Add numpy install dependency.

* Thu Dec 14 2006 Lev Givon <lev@mandriva.org> 0.5.2-2mdv2007.1
+ Revision: 97096
- Add swig dependency.
- Add umfpack dependency.

* Sun Dec 10 2006 Lev Givon <lev@mandriva.org> 0.5.2-1mdv2007.1
+ Revision: 94423
- Update to version 0.5.2.
- Raise release number to permit rebuild against Python 2.5.

* Wed Nov 01 2006 Lev Givon <lev@mandriva.org> 0.5.1-2mdv2007.1
+ Revision: 75027
- Raise release number to placate build system.
- Update to 0.5.1.
- Import python-scipy

* Mon Jul 31 2006 Lev Givon <lev@mandriva.org> 0.5.0-1mdk
- Update.

* Fri May 26 2006 Lev Givon <lev@mandriva.org> 0.4.9-2mdk
- More cleanup.

* Thu May 25 2006 Lev Givon <lev@mandriva.org> 0.4.9-1mdk
- Update version.

* Mon May 22 2006 Lev Givon <lev@mandriva.org> 0.4.8-5mdk
- Make build requirements more concise.

* Sat May 06 2006 Lev Givon <lev@mandriva.org> 0.4.8-4mdk
- Correct license.

* Sat Apr 29 2006 Lev Givon <lev@mandriva.org> 0.4.8-3mdk
- Fix build requirements, build with -fPIC

* Fri Apr 28 2006 Lev Givon <lev@mandriva.org> 0.4.8-2mdk
- Patch signaltools.py bug

* Sun Mar 19 2006 Lev Givon <lev@mandriva.org> 0.4.8-1mdk
- Update version.

* Thu Feb 23 2006 Lev Givon <lev@mandriva.org> 0.4.6-1mdk
- Update version, fine-tune spec file.

* Tue Jan 31 2006 Lev Givon <lev@mandriva.org> 0.4.4-1mdk
- Update version.

* Mon Jan 23 2006 Lev Givon <lev@mandriva.org> 0.4.3-1mdk
- Package new SciPy for Mandriva.

* Fri Oct 07 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 0.3.2-3mdk
- finally build on x86_64 !

* Fri Sep 16 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 0.3.2-2mdk
- requires and use gcc3.3-g77

* Thu Mar 31 2005 Gaetan Lehmann <glehmann@n4.mandrakesoft.com> 0.3.2-1mdk
- initial contrib

